@@ -190,8 +190,16 @@ fn get_field_fields(
 }
 
 fn use_function_for(field: proc_macro2::TokenStream, function: &str) -> proc_macro2::TokenStream {
-    let function = Ident::new(function, proc_macro2::Span::call_site());
-    quote! { #function(&#field) }
+    let path: syn::Result<syn::ExprPath> = syn::parse_str(function);
+    match path {
+        Ok(path) => {
+            quote! { #path(&#field) }
+        }
+        _ => {
+            let function = Ident::new(function, proc_macro2::Span::call_site());
+            quote! { #function(&#field) }
+        }
+    }
 }
 
 fn field_field(field: &Field, index: usize) -> proc_macro2::TokenStream {
